==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi@gmail.com>
 * @author SandorTIHANYI <stihanyi@gmail.com>
 */
$lang['admin_acl']             = 'Hozzáférési lista (ACL) kezelő';
$lang['acl_group']             = 'Csoport:';
$lang['acl_user']              = 'Felhasználó:';
$lang['acl_perms']             = 'Jogosultság ehhez:';
$lang['page']                  = 'oldal';
$lang['namespace']             = 'névtér';
$lang['p_user_id']             = 'A(z) <b class="acluser">%s</b> felhasználónak jelenleg a következő jogosultsága van ezen az oldalon:  <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'A(z) <b class="acluser">%s</b> felhasználónak jelenleg a következő jogosultsága van ebben a névtérben: <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'A(z) <b class="aclgroup">%s</b> csoport tagjainak jelenleg a következő jogosultsága van ezen az oldalon:  <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'A(z) <b class="aclgroup">%s</b> csoport tagjainak jelenleg a következő jogosultsága van ebben a névtérben: <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'A felső formon <b>adjon meg egy felhasználót vagy csoportot</b>, akinek a(z) <b class="aclpage">%s</b> oldalhoz beállított jogosultságait megtekinteni vagy változtatni szeretné.';
$lang['p_choose_ns']           = 'A felső formon <b>adjon meg egy felhasználót vagy csoportot</b>, akinek a(z) <b class="aclns">%s</b> névtérhez beállított jogosultságait megtekinteni vagy változtatni szeretné.';
$lang['p_inherited']           = 'Megjegyzés: ezek a jogok nem itt lettek explicit beállítva, hanem öröklődtek egyéb csoportokból vagy felsőbb névterekből.';
$lang['p_isadmin']             = 'Megjegyzés: a kiválasztott csoportnak vagy felhasználónak mindig teljes jogosultsága lesz, mert Wiki-gazdának van beállítva.';
$lang['current']               = 'Jelenlegi hozzáférési szabályok';
$lang['where']                 = 'Oldal/névtér';
$lang['who']                   = 'Felhasználó/Csoport';
$lang['perm']                  = 'Jogosultságok';
$lang['acl_perm0']             = 'Semmi';
$lang['acl_perm1']             = 'Olvasás';
$lang['acl_perm2']             = 'Szerkesztés';
$lang['acl_perm4']             = 'Létrehozás';
$lang['acl_perm8']             = 'Feltöltés';
$lang['acl_perm16']            = 'Törlés';
$lang['acl_new']               = 'Új bejegyzés hozzáadása';
$lang['acl_mod']               = 'Bejegyzés módosítása';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 */
$lang['admin_acl']             = 'Hozzáférési lista (ACL) kezelő';
$lang['acl_group']             = 'Csoport:';
$lang['acl_user']              = 'Felhasználó:';
$lang['acl_perms']             = 'Jogosultság ehhez:';
$lang['page']                  = 'oldal';
$lang['namespace']             = 'névtér';
$lang['btn_select']            = 'Kiválaszt';
$lang['p_user_id']             = 'A(z) <b class="acluser">%s</b> felhasználónak jelenleg a következő jogosultsága van ezen az oldalon:  <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'A(z) <b class="acluser">%s</b> felhasználónak jelenleg a következő jogosultsága van ebben a névtérben: <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'A(z) <b class="aclgroup">%s</b> csoport tagjainak jelenleg a következő jogosultsága van ezen az oldalon:  <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'A(z) <b class="aclgroup">%s</b> csoport tagjainak jelenleg a következő jogosultsága van ebben a névtérben: <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'A felső formon <b>adjon meg egy felhasználót vagy csoportot</b>, akinek a(z) <b class="aclpage">%s</b> oldalhoz beállított jogosultságait megtekinteni vagy változtatni szeretné.';
$lang['p_choose_ns']           = 'A felső formon <b>adjon meg egy felhasználót vagy csoportot</b>, akinek a(z) <b class="aclns">%s</b> névtérhez beállított jogosultságait megtekinteni vagy változtatni szeretné.';
$lang['p_inherited']           = 'Megjegyzés: ezek a jogok nem itt lettek explicit beállítva, hanem öröklődtek egyéb csoportokból vagy felsőbb névterekből.';
$lang['p_isadmin']             = 'Megjegyzés: a kiválasztott csoportnak vagy felhasználónak mindig teljes jogosultsága lesz, mert Wiki-gazdának van beállítva.';
$lang['p_include']             = 'A magasabb jogok tartalmazzák az alacsonyabbakat.  A Létrehozás, Feltöltés és Törlés jogosultságok csak névterekre alkalmazhatók, az egyes oldalakra nem.';
$lang['current']               = 'Jelenlegi hozzáférési szabályok';
$lang['where']                 = 'Oldal/névtér';
$lang['who']                   = 'Felhasználó/Csoport';
$lang['perm']                  = 'Jogosultságok';
$lang['acl_perm0']             = 'Semmi';
$lang['acl_perm1']             = 'Olvasás';
$lang['acl_perm2']             = 'Szerkesztés';
$lang['acl_perm4']             = 'Létrehozás';
$lang['acl_perm8']             = 'Feltöltés';
$lang['acl_perm16']            = 'Törlés';
$lang['acl_new']               = 'Új bejegyzés hozzáadása';
$lang['acl_mod']               = 'Bejegyzés módosítása';
